#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''
Display Boy's surface in a manner similar to Paraview.
'''

import vtk

nc = vtk.vtkNamedColors()
nc.SetColor('ParaviewBkg', 84, 89, 109)


def BoyActor(zScale = 0.125):
    '''
    Boy's Surface
    '''
    boy = vtk.vtkParametricBoy()
    boy.SetZScale(zScale)
    source = vtk.vtkParametricFunctionSource()
    source.SetParametricFunction(boy)
    source.SetScalarModeToModulus()
    source.Update()

    mapper = vtk.vtkPolyDataMapper()
    mapper.SetInputConnection(source.GetOutputPort())
    mapper.SetScalarRange(source.GetOutput().GetScalarRange())
    actor = vtk.vtkActor()
    actor.SetMapper(mapper)
    return actor

def MakeAxesActor():
    axes = vtk.vtkAxesActor()
    axes.SetShaftTypeToCylinder()
    axes.SetXAxisLabelText('X')
    axes.SetYAxisLabelText('Y')
    axes.SetZAxisLabelText('Z')
    axes.GetXAxisShaftProperty().SetColor(nc.GetColor3d('Red'));
    axes.GetYAxisShaftProperty().SetColor(nc.GetColor3d('Yellow'));
    axes.GetZAxisShaftProperty().SetColor(nc.GetColor3d('Lime'));
    axes.GetXAxisTipProperty().SetColor(nc.GetColor3d('Red'));
    axes.GetYAxisTipProperty().SetColor(nc.GetColor3d('Yellow'));
    axes.GetZAxisTipProperty().SetColor(nc.GetColor3d('Lime'));
    axes.SetTotalLength(1.0, 1.0, 1.0)
    axes.SetCylinderRadius(0.8 * axes.GetCylinderRadius())
    axes.SetConeRadius(1.25 * axes.GetConeRadius())
    tprop = vtk.vtkTextProperty()
    tprop.BoldOn()
    tprop.ItalicOn()
    tprop.ShadowOn()
    tprop.SetFontFamilyToArial()
    tprop.SetFontSize(14)
    axes.GetXAxisCaptionActor2D().SetCaptionTextProperty(tprop)
    axes.GetYAxisCaptionActor2D().SetCaptionTextProperty(tprop)
    axes.GetZAxisCaptionActor2D().SetCaptionTextProperty(tprop)
    axes.GetXAxisCaptionActor2D().GetTextActor().SetTextScaleModeToNone()
    axes.GetYAxisCaptionActor2D().GetTextActor().SetTextScaleModeToNone()
    axes.GetZAxisCaptionActor2D().GetTextActor().SetTextScaleModeToNone()


    return axes

def main():
    ren = vtk.vtkRenderer()
    renWin = vtk.vtkRenderWindow()
    iren = vtk.vtkRenderWindowInteractor()

    renWin.AddRenderer(ren)
    iren.SetRenderWindow(renWin)

    actor = BoyActor()
    ren.AddViewProp(actor)

    axes = MakeAxesActor()
    om = vtk.vtkOrientationMarkerWidget()
    om.SetOrientationMarker(axes)
    om.SetViewport(0,0,0.2,0.2)
    om.SetInteractor(iren)
    om.EnabledOn()
    om.InteractiveOn()

    renWin.SetSize(790, 570)
    ren.ResetCamera()
    ren.SetBackground(nc.GetColor3d('ParaviewBkg'))

    renWin.Render()
    renWin.SetWindowName("Boy's Surface")

    iren.Render()
    iren.Start()

if __name__ == '__main__':
    main()
